/***************************************************************
 * Name:      RoboDudeApp.cpp
 * Purpose:   Code for Application Class
 * Author:    Nils Springob (springob@nicai-systems.de)
 * Created:   2009-10-04
 * Copyright: Nils Springob (http://nibo.nicai-systems.de)
 * License:
 **************************************************************/

#include "BobDudeApp.h"

#include <wx/stdpaths.h>
#include <wx/filename.h>


//(*AppHeaders
#include "MainFrame.h"
#include <wx/image.h>
//*)

IMPLEMENT_APP(BobDudeApp);

MainFrame * frame;

extern MainFrame * frame;
void appendLogLine(const char * text) {
  if (frame) {
    frame->appendLogLine(text);
  }
}

bool BobDudeApp::OnInit() {
  bool wxsOK = true;
  if (!wxApp::OnInit()) {
    wxsOK = false;
  }

  if (m_one.IsAnotherRunning()) {
            // Create a IPC client and use it to ask the existing process to show itself.
            wxClient *client = new wxClient;
            wxConnectionBase *conn = client->MakeConnection("localhost", "/tmp/bobdude_socket_1351a1bebae7", "restart");

            if (files.size()>0) {
              for (unsigned int i=0; i< files.size(); i++) {
                conn->Execute(files[i]);
              }
            } else {
              conn->Execute(".");
            }
            delete conn;
            delete client;
            // Don't enter the message loop.
            return false;
  } else {
      // Start a IPC server.
        m_server = new CServer;
        m_server->Create("/tmp/bobdude_socket_1351a1bebae7");
  }

  wxInitAllImageHandlers();
  if ( wxsOK ) {
    frame = new MainFrame(0);
    frame->Show(true);
    SetTopWindow(frame);
    wxsOK = true;
  }
  return wxsOK;
}

int BobDudeApp::OnExit() {
  delete m_server;
  return this->wxApp::OnExit();
}

void BobDudeApp::OnInitCmdLine(wxCmdLineParser& parser) {
  parser.SetDesc (g_cmdLineDesc);
  // must refuse '/' as parameter starter or cannot use "/path" style paths
  parser.SetSwitchChars (wxT("-"));
}

bool BobDudeApp::OnCmdLineParsed(wxCmdLineParser& parser) {
  // to get at your unnamed parameters use

  for (unsigned int i = 0; i < parser.GetParamCount(); i++) {
    files.Add(parser.GetParam(i));
  }

  wxString configFile;
  // and other command line parameters
  if (parser.Found( wxT("c"), &configFile)) {
  } else {
#if defined(AVRDUDE_CONF)
    configFile = AVRDUDE_CONF;
#else
    configFile = ::wxStandardPaths::Get().GetDataDir() + ::wxFileName::GetPathSeparator() + "avrdude.conf";
#endif
  }
  // then do what you need with them.
  conf = configFile;
  avrdude = new Avrdude("BobDude", static_cast<const char*>(configFile));

  return true;
}

void BobDudeApp::MacOpenFile(const wxString &fileName) {
  frame->loadFile(fileName);
}


bool CConnection::OnExec(const wxString& topic, const wxString& data) {
    if (topic.compare("restart") == 0) {
        frame->Show(true);
        frame->Restore();
        frame->Raise();
        if (data.compare(".")==0) {
          //appendLogLine("[no file]");
        } else {
          appendLogLine("\n----------------------------\n");
          frame->loadFile(data);
        }
    }
    return true;
}
